@@ -34,7 +34,7 @@ use experimental qw( lexical_subs postderef signatures );
 
 use namespace::autoclean;
 
-our $VERSION = 'v0.1.0';
+our $VERSION = 'v0.1.1';
 
 sub mvp_multivalue_args { qw( sections ) }
 
@@ -240,7 +240,7 @@ sub after_build( $self, $build ) {
     }
 }
 
-sub after_release($self) {
+sub after_release( $self, @ ) {
     $self->_create_readme( $self->zilla->root ) if $self->phase eq 'release';
 }
 
@@ -384,7 +384,7 @@ Dist::Zilla::Plugin::UsefulReadme - generate a README file with the useful bits
 
 =head1 VERSION
 
-version v0.1.0
+version v0.1.1
 
 =head1 SYNOPSIS
 
