@@ -7,6 +7,7 @@ use v5.20;
 use Moose;
 with 'Pod::Weaver::Role::Section';
 
+use List::Util qw( first );
 use MooseX::MungeHas;
 use Perl::PrereqScanner 1.024;
 use Pod::Elemental::Element::Nested;
@@ -19,7 +20,7 @@ use experimental qw( lexical_subs postderef signatures );
 
 use namespace::autoclean;
 
-our $VERSION = 'v0.1.0';
+our $VERSION = 'v0.1.1';
 
 
 has header => (
@@ -35,6 +36,13 @@ has region => (
     default => '',
 );
 
+
+has metafile => (
+    is      => 'lazy',
+    isa     => SimpleStr,
+    default => 'cpanfile',
+);
+
 sub weave_section( $self, $document, $input ) {
 
     my $zilla = $input->{zilla};
@@ -102,6 +110,14 @@ sub weave_section( $self, $document, $input ) {
         }
     );
 
+    my %files = map { $_->name => 1 } $zilla->files->@*;
+    my @metafiles = grep { $_ ne '' } ( $self->metafile, qw( cpanfile META.json META.yml ) );
+    if ( my $file = first { $files{$_} } @metafiles ) {
+        push $res->children->@*,
+          Pod::Elemental::Element::Pod5::Ordinary->new(
+            { content => "See the F<${file}> file for the full list of prerequisites." } );
+    }
+
     if ( my $name = $self->region ) {
 
         push $document->children->@*,
@@ -135,7 +151,9 @@ Pod::Weaver::Section::Requirements - generate POD with the runtime requirements
 
 =head1 VERSION
 
-version v0.1.0
+version v0.1.1
+
+=for stopwords metafile
 
 =head1 SYNOPSIS
 
@@ -163,6 +181,10 @@ When set to a non-empty string, the section will be embedded in a POD region, e.
 
 to make the region available for L<Dist::Zilla::Plugin::UsefulReadme> or L<Pod::Readme>.
 
+=head2 metafile
+
+A file that lists metadata about prerequisites. It defaults to C<cpanfile>.
+
 =head1 KNOWN ISSUES
 
 When this is used to insert a section into the POD of a module, that it will only show the requirements for that module,
